@@ -3,14 +3,16 @@ Adds setenv for unix.
 """
 
 import os
-from functools import cache
+from typing import Optional
 
 from .util import read_utf8, write_utf8
 
 
-@cache
 def get_target() -> str:
     """Returns the target file."""
+    if os.environ.get("SETENVIRONMENT_CONFIG_FILE"):
+        config_file = os.environ["SETENVIRONMENT_CONFIG_FILE"]
+        return os.path.expanduser(config_file)
     # Get the dictionary attached to
     bashrc = os.path.expanduser("~/.bashrc")
     if ".bash_profile" not in read_utf8(bashrc):
@@ -18,6 +20,11 @@ def get_target() -> str:
     return os.path.expanduser("~/.bash_profile")
 
 
+def set_env_config_file(filepath: str) -> None:
+    """Sets the target file."""
+    os.environ["SETENVIRONMENT_CONFIG_FILE"] = filepath
+
+
 def set_env_var(name: str, value: str) -> None:
     """Sets an environment variable."""
     os.environ[name] = str(value)
@@ -40,6 +47,15 @@ def set_env_var(name: str, value: str) -> None:
         write_utf8(settings_file, new_file)
 
 
+def get_env_var(name: str) -> Optional[str]:
+    """Gets an environment variable."""
+    filelines = read_utf8(get_target()).splitlines()
+    for line in filelines:
+        if line.startswith("export " + name + "="):
+            return line.split("=")[1].strip()
+    return None
+
+
 def unset_env_var(name: str) -> None:
     """Unsets an environment variable."""
     if name in os.environ:
